@@ -31,6 +31,18 @@ pub type ResponseHandle = u32;
 /// An alias for `u32` to denote which ABI arguments represent `DictionaryHandle`s.
 pub type DictionaryHandle = u32;
 
+bitflags::bitflags! {
+    /// `Content-Encoding` codings.
+    ///
+    /// This type must match the definition in `typename.witx`, and will be replaced once we
+    /// generate Wasm-side bindings from witx.
+    #[derive(Default)]
+    #[repr(transparent)]
+    pub struct ContentEncodings: u32 {
+        const GZIP = 1 << 0;
+    }
+}
+
 pub mod fastly_abi {
     use super::*;
 
@@ -354,6 +366,12 @@ pub mod fastly_http_req {
 
         #[link_name = "close"]
         pub fn close(req_handle: RequestHandle) -> FastlyStatus;
+
+        #[link_name = "auto_decompress_response_set"]
+        pub fn auto_decompress_response_set(
+            req_handle: RequestHandle,
+            encodings: ContentEncodings,
+        ) -> FastlyStatus;
     }
 }
 
